<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Paweł Jan Czochański <czochanski@gmail.com>
 */
$lang['server']                = 'Twój server MySQL';
$lang['user']                  = 'Nazwa użytkownika MySQL';
$lang['password']              = 'Hasło dla powyższego użytkownika';
$lang['database']              = 'Używana baza danych';
$lang['charset']               = 'Zestaw znaków uzyty w bazie danych';
$lang['debug']                 = 'Wyświetlaj dodatkowe informacje do debugowania.';
$lang['checkPass']             = 'Zapytanie SQL wykorzystywane do sprawdzania haseł.';
